'MODECALC.BAS - Copyright 2004-2011 Ethan Winer and RealTraps. All rights reserved.

'This program calculates the first 16 axial room modes up to 500 Hz.

'===========================================================
NOMAINWIN

'common variables and arrays
GLOBAL Quote$, Metric
Quote$ = CHR$(34)
Mask$ = "####.##"                           'format display of frequencies
DIM Modes(3)                                'allows referencing L,W,H values by an index
DIM ModeWeights(3, 16)                      'Length/Width/Height, Mode Number (up to 16)
DIM ModePositions(3, 16)                    'mode left/right display positions

DIM Colors$(3)                              'allows referencing L,W,H colors by an index
Colors$(1) = "Blue"
Colors$(2) = "Black"
Colors$(3) = "Red"

TEXTBOX #Main.Length, 100, 65, 70, 22
TEXTBOX #Main.Width, 280, 65, 70, 22
TEXTBOX #Main.Height, 460, 65, 70, 22
STYLEBITS #Main.Plot, _BS_DEFPUSHBUTTON, 0, 0, 0
BUTTON #Main.Plot, "&Graphics Plot", [Plot], UL, 14, 480, 90, 20
BUTTON #Main.Table, "&Frequency Table", [Table], UL, 109, 480, 105, 20
BUTTON #Main.Help, "&Help", [Help], UL, 219, 480, 50, 20
BUTTON #Main.Print, "&Print", [Print], UL, 274, 480, 50, 20
BUTTON #Main.Quit, "&Quit", [Quit], UL, 329, 480, 50, 20
LOADBMP "RTLogo", "RTLogo.bmp"

WindowWidth = 640
WindowHeight = 540
'use last window position, or center the window if ModeCalc was never run
IF FileExist() THEN
  OPEN "ModeCalc.ini" FOR INPUT AS #Ini
  INPUT #Ini, UpperLeftX
  INPUT #Ini, UpperLeftY
  CLOSE #Ini
ELSE
  UpperLeftX = (DisplayWidth - WindowWidth) / 2
  UpperLeftY = (DisplayHeight - WindowHeight) / 2
END IF
OPEN "RealTraps ModeCalc" FOR GRAPHICS_nf_nsb AS #Main
PRINT #Main, "trapclose [Quit]"

'===========================================================
PRINT #Main.Plot, "!font Arial 8 bold"
PRINT #Main.Table, "!font Arial 8 bold"
PRINT #Main.Plot, "!font Arial 8 bold"
PRINT #Main.Help, "!font Arial 8 bold"
PRINT #Main.Print, "!font Arial 8 bold"
PRINT #Main.Quit, "!font Arial 8 bold"
PRINT #Main, "font Arial 12 bold"

'Clear entire screen to light gray
PRINT #Main, "DOWN"
PRINT #Main, "backcolor lightgray"
PRINT #Main, "PLACE 0 0";
PRINT #Main, "boxfilled "; WindowWidth; " "; WindowHeight
PRINT #Main, "backcolor white"
GOSUB [ClearWindow]

PRINT #Main, "COLOR 255 100 0"  'the RealTraps logo color is 255 137 20
CALL PrintCentered "ModeCalc - Graphical Mode Calculator", 18

PRINT #Main, "font Arial 12 bold"
PRINT #Main, "COLOR Blue"
CALL PrintCentered "www.realtraps.com", 36

PRINT #Main, "font Arial 8 italic"
PRINT #Main, "COLOR Black"
CALL PrintCentered "Copyright  2004-2011 RealTraps. All rights reserved.", 53

PRINT #Main, "font Arial 10 bold"
PRINT #Main, "COLOR Blue"
PRINT #Main, "PLACE 47 80";
PRINT #Main, "\Length:"
PRINT #Main, "COLOR Black"
PRINT #Main, "PLACE 234 80";
PRINT #Main, "\Width:"
PRINT #Main, "COLOR Red"
PRINT #Main, "PLACE 409 80";
PRINT #Main, "\Height:"

PRINT #Main, "drawbmp RTLogo 385 460"

'===========================================================
'Print instructions at the bottom
PRINT #Main, "font Arial 10"
PRINT #Main, "COLOR Black"
CALL PrintCentered "Enter the room dimensions using either feet and inches, or meters and centimeters. For example,", 418
CALL PrintCentered "you can enter 12' 6"; Quote$; " or 12.5 for 12.5 feet, or 5 m or 500cm for 5 Meters. Then click either Calculate", 435
CALL PrintCentered "button to generate a graphical representation of the axial modes or a text table of the frequencies.", 452
PRINT #Main, "PLACE 35 476";
PRINT #Main, "font Arial 8 bold"
PRINT #Main, "\Calculate"
PRINT #Main, "PLACE 136 476";
PRINT #Main, "\Calculate"
PRINT #Main, "FLUSH"

'===========================================================
[StartAgain]
PRINT #Main.Length, "!setfocus";
WAIT


[Plot]
GOSUB [Calculate]                           'display the frequencies in the window as text
GOSUB [ClearWindow]                         'clear any previous numbers or graphics
PRINT #Main, "COLOR DarkGray"
PRINT #Main, "SIZE 5"                       'sets line thickness for baseline
PRINT #Main, "LINE 10 310 620 310"          'draw the baselines
PRINT #Main, "SIZE 2"
PRINT #Main, "LINE 10 120 620 120"

'draw a semi-log grid and label the bottom with frequencies under the baseline
PRINT #Main, "font Courier_New 8"
PRINT #Main, "SIZE 1"                       'sets line thickness for grid
FOR X = 10 TO 510 STEP 10
  Position = ((LOG(X) * 90) - 200) * 1.7
  'grid lines every 10 Hz below 200 Hz,every 50 Hz above
  IF (X <= 200) OR ((X MOD 50) = 0) THEN
    PRINT #Main, "LINE "; Position + 2; " 120 "; Position + 2; " 310"
  END IF
  'labels every 10 Hz below 100 Hz, every 50 Hz below 300 Hz, every 100 above
  IF (X <= 100) OR (X <= 300 AND ((X MOD 50) = 0)) OR ((X MOD 100) = 0) THEN
    PRINT #Main, "PLACE "; Position - 6; " 325";
    PRINT #Main, "\"; X
    PRINT #Main, "PLACE "; Position - 6; " 115";
    PRINT #Main, "\"; X
  END IF
NEXT
PRINT #Main, "COLOR LightGray"
PRINT #Main, "LINE 15 250 "; WindowWidth -26; " 250"


'Calculate all the modes and fill the ModePositions
Modes(1) = LengthMode
Modes(2) = WidthMode
Modes(3) = HeightMode
FOR X = 1 TO 16
  FOR Y = 1 TO 3
    ThisMode = Modes(Y) * X                 'current mode
    IF ThisMode > 0 AND ThisMode <= 500 THEN
      ModePositions(Y, X) = ((LOG(ThisMode) * 90) - 200) * 1.7
    ELSE
      ModePositions(Y, X) = 0               'flag that this mode is not used
    END IF
  NEXT
NEXT

'Set the weighting based on the nearness of other modes
'
'The ModeWeights array holds a weighting for each mode's closeness to other modes.
'The calculations are actually done using pixel positions - one octave is 53 pixels
'so each 1/3 octave encompasses 18 pixels. The values stored range from 0 (no mode
'is within 1/3 octave) to 18 (one other mode is within 1 pixel or VERY close), but
'even higher values are likely when more than one other mode is within 13 octave.
'
'First clear any previous weightings.
FOR Y = 1 TO 3
  FOR X = 1 TO 16
    ModeWeights(Y, X) = 0
  NEXT
NEXT

FOR Y = 1 TO 3
  FOR X = 1 TO 16
    ThisPosition = ModePositions(Y, X)
    IF ThisPosition = 0 THEN EXIT FOR       'this mode won't be plotted so no sense looking further
    FOR A = 1 TO 3                          'compare this pixel position to all others
      FOR B = 1 TO 16
        IF A = Y AND B = X THEN
          'ignore thyself
        ELSE
          ThisModePos = ModePositions(A, B)
          IF ThisModePos = 0 THEN EXIT FOR  'dimension was not entered, or we're past 500 Hz
          Difference = ABS(ThisPosition - ModePositions(A, B))
          IF Difference <= 18 THEN          'there's another pixel within 1/3 octave
            Adjustment = (18 - Difference) * 1.5
            ModeWeights(Y, X) = ModeWeights(Y, X) + Adjustment
          END IF
        END IF
      NEXT
    NEXT
  NEXT
NEXT

'Plot the modes
PRINT #Main, "SIZE 2"                       'sets line thickness for blips
FOR X = 1 TO 16
  FOR Y = 1 TO 3
    ThisPosition = ModePositions(Y, X) + 2  'the +2 fudges the display's horizontl placement
    IF ThisPosition > 2 THEN                'so check for >2 instead of >0
      PRINT #Main, "COLOR "; Colors$(Y)
      ThisHeight = 250 - ModeWeights(Y, X)
      PRINT #Main, "LINE "; ThisPosition; " "; ThisHeight; " "; ThisPosition; " 308"
    END IF
  NEXT
NEXT

GOSUB [DisplayRatio]
PRINT #Main, "FLUSH"
GOTO [StartAgain]


[Table]
GOSUB [Calculate]                           'Display the frequencies in the window as text
PRINT #Main, "font Courier_New 10 bold"     'non-prop font we're sure they'll have
GOSUB [ClearWindow]                         'clear any previous numbers or graphics
FOR X = 1 TO 16                             'display first 16 modes up to 500 Hz
  ThisMode = LengthMode * X
  PRINT #Main, "font Courier_New 10 bold"
  PRINT #Main, "COLOR Blue"
  PRINT #Main, "PLACE 102 "; 94 + (X * 15)
  IF ThisMode > 0 AND ThisMode <= 500 THEN PRINT #Main, "\"; USING (Mask$, ThisMode)
  ThisMode = WidthMode * X
  PRINT #Main, "COLOR Black"
  PRINT #Main, "PLACE 282 "; 94 + (X * 15)
  IF ThisMode > 0 AND ThisMode <= 500 THEN PRINT #Main, "\"; USING (Mask$, ThisMode)
  ThisMode = HeightMode * X
  PRINT #Main, "COLOR Red"
  PRINT #Main, "PLACE 462 "; 94 + (X * 15)
  IF ThisMode > 0 AND ThisMode <= 500 THEN PRINT #Main, "\"; USING (Mask$, ThisMode)
NEXT

GOSUB [DisplayRatio]
PRINT #Main, "FLUSH"
GOTO [StartAgain]


'===========================================================
[Help]
'core portions are from LB Newsletter #115
IF HelpOpen THEN GOTO [StartAgain]
HelpOpen = -1
WindowWidth = 640
WindowHeight = 400
UpperLeftX = ((DisplayWidth - WindowWidth) / 2) + 100
UpperLeftY = ((DisplayHeight - WindowHeight) / 2) + 100

RESTORE [ReadHelp]
READ NumLines
Display$ = ""

IF WindowsVersion() < 5 THEN                'This is Windows 95 or 98
  TEXTEDITOR #Help.TEdit, 10, 1, 613, 347   'use a standard text box
  OPEN "ModeCalc Help" FOR WINDOW AS #Help
  PRINT #Help, "trapclose [QuitHelp]"
  PRINT #Help.TEdit, "!font Arial 11"
  FOR X = 1 TO NumLines
    READ Text$                              'discard all control codes
    IF Text$ = "\par" THEN Text$ = ""
    IF INSTR(Text$, "\") = 0 AND INSTR(Text$, "020b") = 0 THEN
      Display$ = Display$ + Text$ + CHR$(13)
    END IF
  NEXT
  PRINT #Help.TEdit, Display$               'fill the window with text
  PRINT #Help.TEdit, "!origin 1 1";         'set the text box to display the first line
ELSE                                        'This is Windows XP, use RichText
  OPEN "ModeCalc Help" FOR WINDOW_NF AS #Help
  PRINT #Help, "trapclose [QuitHelp]"
  FOR X = 1 TO NumLines
    READ Text$
    Display$ = Display$ + Text$ + " "
  NEXT

  GLOBAL Winclass$, hRTFLIB
  CallDLL #kernel32, "LoadLibraryA", "RICHED32.DLL" AS PTR, hRTFLIB AS LONG
  Winclass$ = "RICHEDIT"
  CallDLL #comctl32, "InitCommonControlsEx", Result AS Void
  hT = CreateTextEdit(hWnd(#Help), 10, 10, WindowWidth - 25, WindowHeight-45)

  'The first line below clears the window so scroll bars work correctly
  'with long files - Courtesy of John Davidson
  CALL SetWindowText hT, ""
  CALL SetWindowText hT, Display$ 'Put text into window

  'Set focus into the Help display so the mouse wheel will scroll without
  'having to click inside the window first. hT is the handle of the Help control
  'returned by CreateTextEdit above, and hPrevious is the handle of the control
  'that previously had focus (which is not needed here).
  CallDLL #user32, "SetFocus", hT AS ULong, hPrevious AS ULong
END IF
WAIT


[Print]                                     'send the data to the printer
PrinterDialog
IF PrinterName$ <> "" THEN
 'PRINT #Main, "Print SVGA"                 'Paper width simulates 800 pixels wide
 'PRINT #Main, "Print VGA"
  PRINT #Main, "Print"
END IF
GOTO [StartAgain]


[DisplayRatio]
IF Length = 0 OR Width = 0 OR Height = 0 THEN RETURN
PRINT #Main, "BACKCOLOR LightGray"
PRINT #Main, "COLOR DarkCyan"
PRINT #Main, "PLACE 10 354"
PRINT #Main, "font Arial 9 bold"
PRINT #Main, "\This ratio (HWL):";
PRINT #Main, "COLOR Black"
PRINT #Main, "PLACE 107 354"
PRINT #Main, "font Arial 9 italic"
PRINT #Main, "\ 1 : "; USING ("#.##", Width / Height); " : "; USING ("#.##", Length / Height)
PRINT #Main, "PLACE 197 354"
PRINT #Main, "\"; SPACE$(5); "Length / Width = "; USING ("#.##", Length / Width); SPACE$(10)
PRINT #Main, "COLOR DarkCyan"
PRINT #Main, "PLACE 475 354"
PRINT #Main, "font Arial 9 bold"
PRINT #Main, "\This volume: ";
PRINT #Main, "COLOR Black"
PRINT #Main, "PLACE 551 354"
PRINT #Main, "font Arial 9 italic"
Volume = Height * Width * Length
ID$ = "Cu Ft"
Min$ = "2500 Cubic Feet"
If Metric THEN
  Volume = Volume * 0.02832
  ID$ = "Cu Mt"
  Min$ = "70 Cubic Meters"
END IF
PRINT #Main, "\"; TRIM$(USING("#######", Volume)); " "; ID$; SPACE$(8)
PRINT #Main, "COLOR DarkCyan"
PRINT #Main, "PLACE 17 375"
PRINT #Main, "font Arial 9 bold"
PRINT #Main, "\Recommended "
PRINT #Main, "PLACE 64 390"
PRINT #Main, "\Ratios: "
PRINT #Main, "COLOR Black"
PRINT #Main, "PLACE 110 375"
PRINT #Main, "font Arial 9 italic"
PRINT #Main, "\1 : 1.14 : 1.39      1 : 1.26 : 1.59      1 : 1.28 : 1.54       1 : 1.30 : 1.90";
PRINT #Main, "PLACE 110 390"
PRINT #Main, "\1 : 1.40 : 1.90      1 : 1.50 : 2.10      1 : 1.50 : 2.50       1 : 1.60 : 2.33";
PRINT #Main, "COLOR DarkCyan"
PRINT #Main, "PLACE 475 375"
PRINT #Main, "font Arial 9 bold"
PRINT #Main, "\Recommended Minimum"
PRINT #Main, "PLACE 475 390"
PRINT #Main, "font Arial 9 bold"
PRINT #Main, "\Volume:"
PRINT #Main, "COLOR Black"
PRINT #Main, "PLACE 525 390"
PRINT #Main, "font Arial 9 italic"
PRINT #Main, "\"; Min$; SPACE$(8)
RETURN


[QuitHelp]
HelpOpen = 0
CLOSE #Help
'close whichever RTF interpreter was opened
CallDLL #kernel32,"FreeLibrary", hRTFLIB AS LONG, Ret AS Boolean
GOTO [StartAgain]


[Quit]
'save the current window placement for next time
Struct Rect, x1 AS LONG, y1 AS LONG, x2 AS LONG, y2 AS LONG
Handle = hwnd(#Main)
CallDLL #user32, "GetWindowRect", Handle AS uLong, Rect AS struct, Result AS Long
UpperLeftX = Rect.x1.struct  'left x coord
UpperLeftY = Rect.y1.struct  'upper y coord
OPEN "ModeCalc.ini" FOR OUTPUT AS #Ini
PRINT #Ini, UpperLeftX
PRINT #Ini, UpperLeftY
CLOSE #Ini

'Close all else
CLOSE #Main
UNLOADBMP("RTLogo")
IF HelpOpen THEN
  CLOSE #Help
  'close whichever RTF interpreter was opened
  CallDLL #kernel32,"FreeLibrary", hRTFLIB AS LONG, Ret AS Boolean
END IF
END

'===========================================================
'supporting subroutines
[Calculate]
'Clear any previous entries
LengthMode = 0
WidthMode = 0
HeightMode = 0
'Retrieve current entries
PRINT #Main.Length, "!Contents? Length$"    'read the Length
Length = ConvertToFeet(Length$)             'convert feet/inches/meters/cm to feet
PRINT #Main.Width, "!Contents? Width$"      'read the Width
Width = ConvertToFeet(Width$)
PRINT #Main.Height, "!Contents? Height$"    'read the Height
Height = ConvertToFeet(Height$)
IF Length > 0 THEN LengthMode = 1130 / (Length * 2)
IF Width > 0 THEN WidthMode = 1130 / (Width * 2)
IF Height > 0 THEN HeightMode = 1130 / (Height * 2)
IF Length = 0 AND Width = 0 AND Height = 0 THEN
  NOTICE "You must specify at least one dimension."
  GOTO [StartAgain]
END IF
RETURN


[ClearWindow]
PRINT #Main, "SIZE 2"
PRINT #Main, "COLOR Black"
PRINT #Main, "BackColor White"
PRINT #Main, "PLACE 0 95";
PRINT #Main, "boxfilled "; WindowWidth; " 340"
PRINT #Main, "LINE 0 396 "; WindowWidth; " 396"
RETURN

'===========================================================
'Subs and Functions
SUB PrintCentered Work$, Row
  PRINT #Main, "BACKCOLOR LightGray"
  PRINT #Main, "STRINGWIDTH? Work$ Length"
  PRINT #Main, "PLACE "; (WindowWidth - Length) / 2; " "; Row;
  PRINT #Main, "\"; Work$
END SUB

FUNCTION FileExist()                        'checks for presence of ModeCalc.ini
  DIM Exist$(10, 10)                        'FILES below would REDIM as needed
  FILES DefaultDir$, "ModeCalc.ini", Exist$()
  IF VAL(Exist$(0, 0)) > 0 THEN             '(0, 0) holds the number of matching files
    FileExist = -1
  ELSE
    FileExist = 0
  END IF
END FUNCTION


FUNCTION ConvertToFeet(Work$)
  Metric = 0                                'assume feet/inches, for Volume calc
  Temp$ = Work$                             'work with a copy
  cm = INSTR(Temp$, "cm")                   'did they specify centimeters?
  IF cm THEN
    Metric = -1
    Feet = VAL(LEFT$(Temp$, cm - 1)) * 0.0328
    GOTO [Done]
  END IF

  Meters = INSTR(Temp$, "m")                'did they specify meters?
  IF Meters THEN
    Metric = -1
    Feet = VAL(LEFT$(Temp$, Meters - 1)) * 3.281
    GOTO [Done]
  END IF

  'parse feet and inches
  Ft = INSTR(Temp$, "'")                    'did they specify feet?
  IF Ft THEN                                'yes, start with that
    Temp = VAL(LEFT$(Temp$, Ft - 1))        'save how many feet
    Temp$ = MID$(Temp$, Ft + 1)             'keep all to the right only
  END IF
  Inches = INSTR(Temp$, Quote$)             'did they specify inches?
  IF Inches THEN Temp = Temp + VAL(LEFT$(Temp$, Inches - 1)) / 12

  IF Ft = 0 AND Inches = 0 THEN             'only one number with no ' or "
    Feet = VAL(Temp$)                       'so assume feet
  ELSE
    Feet = Temp                             'else use what was extracted above
  END IF

[Done]
  ConvertToFeet = Feet
END FUNCTION


SUB SetWindowText hWnd, Txt$
  CallDLL #user32, "SetWindowTextA", hWnd AS LONG, Txt$ AS PTR, Result AS Void
END SUB


FUNCTION CreateTextEdit(hW, x, y, w, h)
  Style = _WS_CHILDWINDOW OR _WS_BORDER OR _WS_VISIBLE or_
    _ES_MULTILINE OR _WS_VSCROLL OR _ES_READONLY
  hInst=GetWindowLong(hW, _GWL_HINSTANCE)
  CallDLL #user32,"CreateWindowExA", 0 AS long,Winclass$ AS Ptr, "" AS PTR, Style AS LONG,_
    x AS LONG, y AS LONG, w AS LONG, h AS LONG, hW AS LONG, 0 AS LONG, hInst AS LONG,_
    0 AS LONG, CreateTextEdit AS LONG
END FUNCTION


FUNCTION GetWindowLong(hW, Type)
  CallDLL #user32, "GetWindowLongA", hW AS LONG, Type AS LONG, GetWindowLong AS LONG
END FUNCTION


FUNCTION WindowsVersion ()
  STRUCT OSVERSIONINFO, dwOSVersionInfoSize AS LONG,  dwMajorVersion AS LONG, _
  dwMinorVersion AS LONG, dwBuildNumber AS LONG, dwPlatformId AS LONG, _
  szCSDVersion AS CHAR[128]
  L = LEN(OSVERSIONINFO.struct)
  OSVERSIONINFO.dwOSVersionInfoSize.struct = L
  OPEN "kernel32" FOR DLL AS #Kernel
  CallDLL #Kernel, "GetVersionExA", OSVERSIONINFO AS STRUCT, Result AS Boolean
  CLOSE #Kernel
  WindowsVersion = OSVERSIONINFO.dwMajorVersion.struct
  'above assigns major version, 4=Windows 98, 5=Windows XP
  'minor version is returned in OSVERSIONINFO.dwMinorVersion.Struct
END FUNCTION

'===========================================================
[ReadHelp]
DATA 240
DATA "{\rtf1\ansi\ansicpg1252\uc1 \deff0\deflang1033\deflangfe1033{\fonttbl{\f0\froman\fcharset0\fprq2{\*\panose"
DATA "020b0604020202020204}Arial;}"
DATA "{\colortbl ;\red255\green255\blue0;\red255\green0\blue0;\red0\green0\blue255;}"
DATA "{\pntxtb (}{\pntxta )}}\pard\plain \qc\li80\ri-1440\nowidctlpar\widctlpar\adjustright"
DATA "\fs20\cgrid {\f1\cf1\cgrid0 \b \cf3"
DATA "ModeCalc - Graphical Room Mode Calculator"
DATA "\cf0\b0"
DATA "\par }\pard \qc\li80\nowidctlpar\widctlpar\adjustright {\f1\cgrid0 \i Program and Tutorial by Ethan Winer\i0"
DATA "\par}\pard \li80\nowidctlpar\widctlpar\adjustright {\f1\cgrid0 "
DATA "\par"
DATA "ModeCalc calculates and displays the first 16 axial modes, up to 500 Hz,"
DATA "for any rectangular room using dimensions you enter as either feet and"
DATA "inches or meters. It can help you design a new room that sounds as good"
DATA "as possible, or predict the low frequency behavior of an existing room."
DATA "\par"
DATA "\par"
DATA "This tutorial explains the basics of room modes, and tells how to use"
DATA "ModeCalc and interpret its results. Please understand that ModeCalc is"
DATA "not meant to help you determine low frequency treatment for an existing"
DATA "room. Regardless of what is predicted (or measured using test equipment)"
DATA "the solution is always the same - as much broadband bass trapping as you"
DATA "can manage. Whether your current room happens to have favorable dimensions"
DATA "or not is irrelevant, unless you're willing to move the walls!"
DATA "\par"
DATA "\par \b \cf3"
DATA "ROOM MODES"
DATA "\cf0\b0\"
DATA "\par"
DATA "Room modes are natural resonances that occur in every enclosed space,"
DATA "and the frequency of each resonance is directly related to the room's"
DATA "dimensions. For example, a room 16 feet long has a mode at 35 Hz"
DATA "because walls that far apart provide a natural resonance at 35 Hz."
DATA "Additional modes occur at multiples of 35 Hz because those frequencies"
DATA "also resonate in the same space. Wall spacing that accommodates one"
DATA "cycle of a 35 Hz wave also fits two cycles of 70 Hz, three cycles of"
DATA "105 Hz, and so forth."
DATA "\par"
DATA "\par"
DATA "When you play a musical note having the same pitch as a natural"
DATA "resonance of the room, that note will sound louder and have a longer"
DATA "decay time than other notes. Of course, this is undesirable because"
DATA "some notes are emphasized more than others, and the longer decay"
DATA "times reduce clarity. Therefore, room modes are important because they"
DATA "directly affect the character of a room. Although room resonances can"
DATA "be reduced by adding bass traps, they cannot be eliminated entirely."
DATA "\par"
DATA "\par"
DATA "For this reason, rooms for recording and playing music are designed"
DATA "to have many resonances that are distributed evenly, rather than just"
DATA "a few resonances at the same or nearby frequencies. Playing music in"
DATA "a room with poor mode distribution is like listening through a 5-band"
DATA "graphic equalizer with one or two bands turned up all the way. A room"
DATA "with good modes is more like having a 31-band equalizer with all the"
DATA "bands turned up. The frequency response still isn't perfect, but all"
DATA "the small peaks combine to yield an overall response that's reasonably"
DATA "flat. Therefore, the frequency response of a room with many modes"
DATA "close together is flatter overall than a room that has fewer modes"
DATA "farther apart."
DATA "\par"
DATA "\par"
DATA "Small rooms have modes that are spaced farther apart than large rooms"
DATA "because the first mode in a small room starts at a higher frequency."
DATA "For example, when the longest dimension of a room is only 10 feet,"
DATA "the modes for that dimension start at 56.5 Hz and are 56.5 Hz apart."
DATA "In larger rooms the first mode is at a lower frequency so subsequent"
DATA "modes are closer together. Therefore, a large room has a flatter low"
DATA "frequency response because it has more modes spaced more closely."
DATA "\par"
DATA "\par"
DATA "The formula used by ModeCalc is extremely simple. For dimensions"
DATA "given in feet the first mode occurs at 1130 divided by twice the"
DATA "dimension. (1130 is the speed of sound in feet per second.) All"
DATA "subsequent modes are multiples of that result. When using meters the"
DATA "formula is 344 divided by twice the dimension. Twice the dimension"
DATA "is used because a room 10 feet long really has a total distance of"
DATA "20 feet - the wave travels from one end to the other and back to"
DATA "complete one cycle. So for a room 10 feet long the first mode occurs"
DATA "at 56.5 Hz:"
DATA "\par"
DATA "\par \b\cf2"
DATA "   1130 / (10 x 2) = 56.5"
DATA "\cf0\b0"
DATA "\par"
DATA "\par"
DATA "The second mode for that dimension is two times 56.5 or 113 Hz, the"
DATA "third is three times 56.5 or 169.5 Hz, and so forth to the tenth"
DATA "mode at 565 Hz."
DATA "\par"
DATA "\par \b\cf3"
DATA "ROOM RATIOS"
DATA "\cf0\b0"
DATA "\par"
DATA "The worst type of room shape is a perfect cube - say, ten feet long,"
DATA "ten feet wide, and ten feet high - because all three dimensions are"
DATA "the same and all three dimensions resonate at the same frequency. A"
DATA "10 foot cube shaped room will have a strong inherent resonance near"
DATA "55 Hz, which is the open A string on a bass. So when that low A is"
DATA "played it will sound much louder than other notes. Such a room also"
DATA "has a longer natural decay time at that pitch, so A notes will"
DATA "sustain longer and conflict with other bass notes that follow."
DATA "\par"
DATA "\par"
DATA "A room whose dimensions are multiples of each other - for example,"
DATA "10 feet by 20 feet - is nearly as bad because many of the same"
DATA "frequencies are emphasized. Therefore, the goal is to have a room"
DATA "shape that spreads the modes evenly throughout the low frequency"
DATA "range. This is done by designing the room with dimensions whose"
DATA "ratios of length, width, and height are as unrelated as possible."
DATA "And here is where ModeCalc is useful because it tells you at what"
DATA "frequencies the modes occur and how close together they are. ModeCalc"
DATA "also shows you the ratios of the dimensions you entered, and lets"
DATA "you compare them to ratios commonly recommended by acoustic engineers"
DATA "and studio designers."
DATA "\par"
DATA "\par \b\cf3"
DATA "USING MODECALC"
DATA "\cf0\b0"
DATA "\par"
DATA "Instructions at the bottom of the screen explain how to use the program."
DATA "Simply enter the Length, Width, and Height using the Tab and Shift-Tab"
DATA "keys to go between fields, then hit Enter to see the result. Up to 16"
DATA "modes for each room dimension are displayed graphically so you can see"
DATA "where they occur and how they relate to one another. Each set of modes"
DATA "is shown in a different color, and when two or more modes occur near"
DATA "the same frequency the mode lines are drawn taller. Note that the"
DATA "graphic display portion of ModeCalc uses logarithmic spacing. This is"
DATA "how octaves and musical intervals are arranged, and is also how mode"
DATA "spacing should be viewed."
DATA "\par"
DATA "\par"
DATA "You can also enter the room dimensions as meters and/or centimeters"
DATA "instead of feet by using m or M or cm or CM and so forth after the"
DATA "dimension values. Values can be entered with or without spaces, so"
DATA "'10m' and '10 m' both specify 10 meters. Likewise for feet and inches."

DATA "\par"
DATA "\par"
DATA "Professional studio designer Wes Lachot (www.weslachot.com) prefers to"
DATA "consider room ratios in terms of musical intervals, and this table lets"
DATA "you relate your ModeCalc results that way:"
DATA "\par \b\cf2"
DATA "\par"
DATA "    1 : 1.06 - Minor 2nd"
DATA "\par"
DATA "    1 : 1.12 - Major 2nd"
DATA "\par"
DATA "    1 : 1.19 - Minor 3rd"
DATA "\par"
DATA "    1 : 1.26 - Major 3rd"
DATA "\par"
DATA "    1 : 1.33 - Perfect 4th"
DATA "\par"
DATA "    1 : 1.41 - Diminished 5th"
DATA "\par"
DATA "    1 : 1.50 - Perfect 5th"
DATA "\par"
DATA "    1 : 1.59 - Minor 6th"
DATA "\par"
DATA "    1 : 1.68 - Major 6th"
DATA "\par"
DATA "    1 : 1.78 - Minor 7th"
DATA "\par"
DATA "    1 : 1.89 - Major 7th"
DATA "\cf0 \b0"

DATA "\par"
DATA "\par"
DATA "Many rooms are not rectangular, and in fact having angled walls or a"
DATA "vaulted ceiling is desirable. Unfortunately, with angles there is no"
DATA "direct way to determine the room modes exactly. Modes still exist -"
DATA "they're just more difficult to predict. If the angles are not too"
DATA "severe you can average the dimensions. For example, if the ceiling"
DATA "varies from 8 feet to 10 feet high, you can use 9 feet when entering"
DATA "the height."
DATA "\par"
DATA "\par"
DATA "When viewing the results look for an even spacing of the modes"
DATA "regardless of their color (good), and also look for multiple modes"
DATA "that occur at or near the same frequencies (bad). Also compare the"
DATA "ratios of the dimensions you entered with the recommended ratios,"
DATA "and compare your room's volume with the recommended minimum of"
DATA "approximately 2500 cubic feet or 70 cubic meters."
DATA "\par"
DATA "\par"
DATA "To make it easier for you to identify modes that are close together"
DATA "ModeCalc draws those mode lines taller, which simulates the larger"
DATA "response peak that occurs. The normal line height is marked with a"
DATA "thin gray horizontal line. When two modes are adjacent, or at least"
DATA "close, both lines are drawn taller. The closer the modes are to each"
DATA "other, the taller the lines appear. This also lets you identify modes"
DATA "that fall on identical frequencies. ModeCalc draws all the lines for"
DATA "one mode, then the next, and the next. So if several modes are at"
DATA "identical frequencies one line will hide the other. If you notice that"
DATA "an isolated line is higher than usual, that means there are at least"
DATA "two modes at that same frequency. You can then use the Frequency Table"
DATA "display to see them all. Also note that modes naturally become closer"
DATA "at higher frequencies. Therefore, having taller lines toward the right"
DATA "side of the graph is normal, and does not mean your room will really"
DATA "have that rising frequency response."
DATA "\par"
DATA "\par"
DATA "Finally, if you are using ModeCalc to check an existing room, please"
DATA "don't be discouraged by poor results. All rooms need bass trapping"
DATA "anyway, and poor modes can be improved enormously by adding a few"
DATA "more traps. You can also enter dimensions for a large room having"
DATA "one of the recommended ratios, such as 23.3 by 16 by 10 feet. Then"
DATA "you'll see how even with the recommended ratios the modes are still"
DATA "somewhat uneven, and two modes still sometimes occur at the same"
DATA "frequency. So unless you are willing to move the walls, just accept"
DATA "what you have, and maybe install a few more bass traps than you had"
DATA "planned for originally. Then relax and enjoy the music!"
DATA "\par"
DATA "\par \b\cf3"
DATA "A FEW WORDS ABOUT MODE TYPES"
DATA "\cf0\b0\"
DATA "\par"
DATA "There are two basic types of room modes - axial and non-axial. Axial"
DATA "modes occur between two parallel surfaces, where non-axial modes take"
DATA "a more circuitous route travelling much like a cue ball going around"
DATA "a pool table in a diamond pattern. The two non-axial mode types are"
DATA "called Tangential (the reflected waves touch four room surfaces) and"
DATA "Oblique (the waves touch all six surfaces)."
DATA "\par"
DATA "\par"
DATA "Every rectangular room has three axial modes, with one between the"
DATA "floor and ceiling, another between the left and right walls, and"
DATA "another between the front and rear walls. Axial modes are the most"
DATA "important type simply because they are the strongest. They contribute"
DATA "more to peaks and nulls, and modal ringing (extended decays), than"
DATA "non-axial modes. This is because the boundaries are parallel and so"
DATA "the distance between reflections is shorter too. Therefore, axial"
DATA "modes are the most damaging to accurate music reproduction, and the"
DATA "most important type to consider."
DATA "\par"
DATA "\par }\pard \qc\li80\nowidctlpar\widctlpar\adjustright {\f1\cgrid0"
DATA "\i"
DATA "Entire contents copyright (c) 2003-2006 by RealTraps, LLC."
DATA "\i0"
DATA "\par }\pard \qc\nowidctlpar\widctlpar\adjustright {\f1\cgrid0"
DATA "\i"
DATA "All rights reserved. www.realtraps.com"
DATA "}\i0 {\f1"
DATA "\par }}"

